@@ -191,18 +191,27 @@ INVALIDPARAMETERVALUE_VPCNOTFOUND = 'InvalidParameterValue.VpcNotFound'
 # 超过配额限制。
 LIMITEXCEEDED = 'LimitExceeded'
 
+# 集群中节点数超过最大限制。
+LIMITEXCEEDED_CLUSTERINSTANCELIMIT = 'LimitExceeded.ClusterInstanceLimit'
+
 # 用户实例个数超出限制。
 LIMITEXCEEDED_USERINSTANCELIMIT = 'LimitExceeded.UserInstanceLimit'
 
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
+# 权限校验失败。
+OPERATIONDENIED_CAMDENIEDERROR = 'OperationDenied.CamDeniedError'
+
 # 由于操作禁止，当前集群不允许该操作。
 OPERATIONDENIED_CLUSTEROPNOTALLOWEDERROR = 'OperationDenied.ClusterOpNotAllowedError'
 
 # 集群当前状态不允许该操作。
 OPERATIONDENIED_CLUSTERSTATUSDENIEDERROR = 'OperationDenied.ClusterStatusDeniedError'
 
+# 您没有权限操作资源。
+OPERATIONDENIED_INSTANCEACCESSDENIEDERROR = 'OperationDenied.InstanceAccessDeniedError'
+
 # 实例当前状态不允许该操作。
 OPERATIONDENIED_INSTANCESTATUSDENIEDERROR = 'OperationDenied.InstanceStatusDeniedError'
 
