@@ -152,7 +152,7 @@ class EssbasicClient(AbstractClient):
 
 
     def ChannelCreateConvertTaskApi(self, request):
-        """创建文件转换任务
+        """上传了word、excel文件后，通过该接口发起文件转换任务，将word、excel文件转换为pdf文件。
 
         :param request: Request instance for ChannelCreateConvertTaskApi.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateConvertTaskApiRequest`
@@ -421,7 +421,7 @@ class EssbasicClient(AbstractClient):
 
 
     def ChannelCreateUserRoles(self, request):
-        """渠道版绑定员工角色
+        """绑定员工角色
 
         :param request: Request instance for ChannelCreateUserRoles.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateUserRolesRequest`
@@ -444,7 +444,7 @@ class EssbasicClient(AbstractClient):
 
 
     def ChannelDeleteRoleUsers(self, request):
-        """渠道版删除员工绑定角色
+        """删除员工绑定角色
 
         :param request: Request instance for ChannelDeleteRoleUsers.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelDeleteRoleUsersRequest`
@@ -537,7 +537,7 @@ class EssbasicClient(AbstractClient):
 
 
     def ChannelDescribeRoles(self, request):
-        """渠道办查询用户角色
+        """查询用户角色
 
         :param request: Request instance for ChannelDescribeRoles.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelDescribeRolesRequest`
